@@ -50,7 +50,7 @@ reset_stream.DSD <- function(dsd, pos=1) {
 ### helper
 print.DSD <- function(x, ...) {
   cat(.line_break(x$description))
-  #cat("Class:", paste(class(x), collapse=", "), "\n") 
+  cat("Class:", paste(class(x), collapse=", "), "\n") 
   cat(paste('With', x$k, 'clusters', 'in', x$d, 'dimensions', '\n'))
 }
 
