@@ -141,8 +141,9 @@ reset_stream.DSD_MG <- function(dsd, pos=1) {
 }
 
 print.DSD_MG <- function(x, ...) {
+  #NextMethod()
   cat(.line_break(paste(x$description)))
-  #cat("Class:", paste(class(x), collapse=", "), "\n")
+  cat("Class:", paste(class(x), collapse=", "), "\n")
   cat(paste('With', length(na.omit(unique(x$RObj$labels))), 'clusters', 'in', 
     x$RObj$dimension, 'dimensions. Time is', round(x$RObj$t, 3), '\n'))
 }
